From 3c9c3b19fcb212171036e1e57e749411b5fd7d65 Mon Sep 17 00:00:00 2001
From: Sobhan Mohammadpour <sobhanmohammadpour1@yahoo.fr>
Date: Thu, 28 Feb 2013 18:48:32 +0330
Subject: [PATCH 2/3] Make bluetooth support optional

https://bugs.gentoo.org/show_bug.cgi?id=398145

Ed Catmur 2012-01-08 13:46:22 UTC
libgnome-bluetooth-applet is a private library so they shouldn't be linking
against it anyway.  I tried to work out how to tell libtool to add it to rpath
but got totally lost.

I'll see if I can work out how to fix the automagic gnome-bluetooth dependency
so I can at least merge USE=-bluetooth.
---
 configure.ac | 16 +++++++++++++---
 1 file changed, 13 insertions(+), 3 deletions(-)

diff --git a/configure.ac b/configure.ac
index 9a30e65..aa710f0 100644
--- a/configure.ac
+++ b/configure.ac
@@ -138,11 +138,21 @@ AS_IF([test x$enable_browser_plugin = xyes], [
 ])
 AM_CONDITIONAL(BUILD_BROWSER_PLUGIN, test x$enable_browser_plugin = xyes)
 
+AC_MSG_CHECKING([for bluetooth support])
+AC_ARG_WITH([bluetooth],
+	AS_HELP_STRING([--without-bluetooth],
+		[Build without gnome-bluetooth library (default: auto)]))
+AS_IF([test "x$with_bluetooth" != "xno"], [
 PKG_CHECK_MODULES(BLUETOOTH, gnome-bluetooth-1.0 >= 3.9.0,
-        [AC_DEFINE([HAVE_BLUETOOTH],[1],[Define if you have libgnome-bluetooth-applet])
-	 AC_SUBST([HAVE_BLUETOOTH],[1])],
+	[AC_DEFINE([HAVE_BLUETOOTH],[1],[Define if you have libgnome-bluetooth-applet])
+	 AC_SUBST([HAVE_BLUETOOTH],[1])
+	 AC_MSG_RESULT([yes])],
 	[AC_DEFINE([HAVE_BLUETOOTH],[0])
-	 AC_SUBST([HAVE_BLUETOOTH],[0])])
+	 AC_SUBST([HAVE_BLUETOOTH],[0])
+	 AC_MSG_RESULT([no])])
+], [AC_DEFINE([HAVE_BLUETOOTH],[0])
+	 AC_SUBST([HAVE_BLUETOOTH],[0])
+	 AC_MSG_RESULT([no])])
 
 PKG_CHECK_MODULES(CALENDAR_SERVER, libecal-1.2 >= $LIBECAL_MIN_VERSION libedataserver-1.2 >= $LIBEDATASERVER_MIN_VERSION gio-2.0)
 AC_SUBST(CALENDAR_SERVER_CFLAGS)
-- 
1.9.0

